@@ -16,7 +16,7 @@ from typing import Dict, Tuple  # noqa: F401
 
 import dials.util.version
 
-__version__ = "0.206"
+__version__ = "0.207"
 
 logger = logging.getLogger("dials.screen19")
 debug, info, warn = logger.debug, logger.info, logger.warning
@@ -91,13 +91,13 @@ def make_template(f):
     directory, f = os.path.split(f)
     # Split off the file extension, assuming it begins at the first full stop,
     # also split the last contiguous group of digits off the filename root
-    parts = re.split(r"([0-9]+)(?=\.\w)", f, 1)
+    parts = re.split(r"([0-9#]+)(?=\.\w)", f, 1)
     # Get the number of digits in the group we just isolated and their value
     try:
         # Combine the root, a hash for each digit and the extension
         length = len(parts[1])
         template = parts[0] + "#" * length + parts[2]
-        image = int(parts[1])
+        image = int(parts[1].replace("#", "0"))
     except IndexError:
         template = parts[0]
         image = None
