@@ -37,22 +37,24 @@ Examples:
 
 from __future__ import absolute_import, division, print_function
 
-import sys
 import logging
 import numpy as np
 from tabulate import tabulate
-from typing import Iterable, List, Optional, Sequence, Union  # noqa: F401
+import time
+
 # Flake8 does not detect typing yet (https://gitlab.com/pycqa/flake8/issues/342)
+from typing import Iterable, List, Optional, Sequence, Union  # noqa: F401
 
 import boost.python
 from cctbx import crystal, miller
 from dials.array_family import flex
 from dials.util.options import OptionParser
+from dials.util.version import dials_version
 from dxtbx.model import Experiment, ExperimentList
 import iotbx.phil
 from libtbx.phil import scope, scope_extract
 from scipy.optimize import curve_fit
-from screen19 import d_ticks, dials_v1, plot_intensities, terminal_size
+from screen19 import d_ticks, dials_v1, plot_intensities, terminal_size, __version__
 
 
 # Custom types
@@ -125,7 +127,8 @@ phil_scope = iotbx.phil.parse(
                     "a different extension, either '.pdf', '.ps', '.eps' or '.svg', " \
                     "a file of that format will be created instead."
         }
-        """ + verbosity_scope,
+        """
+    + verbosity_scope,
     process_includes=True,
 )
 
@@ -190,11 +193,11 @@ def wilson_fit(d_star_sq, intensity, sigma, wilson_fit_max_d):
 
 
 def wilson_plot_ascii(
-        crystal_symmetry,  # type: crystal.symmetry
-        indices,  # type: Sequence[flex.miller_index, ...]
-        intensity,  # type: FloatSequence
-        sigma,  # type: FloatSequence
-        d_ticks=None,  # type: Optional[FloatSequence]
+    crystal_symmetry,  # type: crystal.symmetry
+    indices,  # type: Sequence[flex.miller_index, ...]
+    intensity,  # type: FloatSequence
+    sigma,  # type: FloatSequence
+    d_ticks=None,  # type: Optional[FloatSequence]
 ):
     # type: (...) -> None
     u"""
@@ -217,7 +220,7 @@ def wilson_plot_ascii(
     )
     ma = miller.array(ms, data=intensity, sigmas=sigma)
     ma.set_observation_type_xray_intensity()
-    ma.setup_binner_counting_sorted(n_bins=n_bins)
+    ma.setup_binner_counting_sorted(n_bins=n_bins, reflections_per_bin=1)
     wilson = ma.wilson_plot(use_binning=True)
     # Get the relevant plot data from the miller_array:
     binned_intensity = [x if x else 0 for x in wilson.data[1:-1]]
@@ -245,7 +248,7 @@ def wilson_plot_image(
     fit,  # type: Fit
     max_d=None,  # type: Optional[float]
     ticks=None,  # type: Optional[FloatSequence]
-    output="wilson_plot"  # type: str
+    output="wilson_plot",  # type: str
 ):
     # type: (...) -> None
     u"""
@@ -389,7 +392,8 @@ def suggest_minimum_exposure(expts, refls, params):
             u"The estimated minimal sufficient exposure (flux × exposure time) to "
             u"achievea resolution of %.2g Å is %.3g times the exposure used for this "
             "data collection.",
-            target, recommendation,
+            target,
+            recommendation,
         )
 
     summary = "\nRecommendations, summarised:\n"
@@ -399,9 +403,11 @@ def suggest_minimum_exposure(expts, refls, params):
         floatfmt=(".2g", ".3g"),
         tablefmt="rst",
     )
-    summary += u"\nExposure is flux × exposure time." \
-               "\nYou can achieve your desired exposure factor by modifying " \
-               "transmission and/or exposure time."
+    summary += (
+        u"\nExposure is flux × exposure time."
+        "\nYou can achieve your desired exposure factor by modifying "
+        "transmission and/or exposure time."
+    )
     info(summary)
 
     # Draw the Wilson plot image and save to file
@@ -446,13 +452,23 @@ def run(phil=phil_scope, args=None, set_up_logging=False):
         from dials.util import log
 
         # Configure the logging
-        log.config(
-            params.verbosity, info=params.output.log, debug=params.output.debug_log
-        )
+        if dials_v1:
+            log.config(
+                params.verbosity, info=params.output.log, debug=params.output.debug_log
+            )
+        else:
+            log.config(params.verbosity, params.output.log)
 
     if not (params.input.experiments and params.input.reflections):
+        version_information = "screen19.minimum_exposure v%s using %s (%s)" % (
+            __version__,
+            dials_version(),
+            time.strftime("%Y-%m-%d %H:%M:%S"),
+        )
+
         print(help_message)
-        sys.exit(1)
+        print(version_information)
+        return
 
     if len(params.input.experiments) > 1:
         warn(
